.. tackle box documentation master file, created by
   sphinx-quickstart on Thu Jul 11 11:31:49 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Tackle Box
==========

Declarative DSL for creating workflows, CLIs, and generating code. Extends cookiecutter templates with modules, loops, conditionals, and plugin based hooks to perform a wide array of actions.

Basics
------

.. toctree::
   :maxdepth: 1

   README
   overview
   installation-tackle
   demos
   usage
   tutorials
   tutorial1
   tutorial2
   advanced/index
   troubleshooting

Providers Reference
-------------------

.. toctree::
   :glob:
   :maxdepth: 1
   :name: API

   tackle.providers*
..   modules


.. _apiref:


API Reference
-------------

.. toctree::
   :glob:
   :maxdepth: 1
   :name: API

   tackle
   tackle.cli
   tackle.parser*
   tackle.render
   tackle.utils


Project Info
------------

.. toctree::
   :maxdepth: 2

   HISTORY
..   CONTRIBUTING
   AUTHORS
   sprint-contributors
   HISTORY
   case_studies
   BACKERS
   CODE_OF_CONDUCT

API Reference
-------------

.. toctree::
   :glob:
   :maxdepth: 1
   :name: API

   hooks/*


Index
-----

* :ref:`genindex`
* :ref:`modindex`
